import type { Path } from '@/router'
import { useNavigate } from '@/router'
import { Button } from '@blueprintjs/core'
import { css } from '@emotion/css'
import type { FC, ReactNode } from 'react'
import { memo } from 'react'

const editorPage = css`
  display: grid;
  grid-template-rows: auto auto 1fr auto;
  height: 100vh;
  padding-right: 0.5rem;
`

interface EditorPageProps {
  title: string
  description: string
  children: ReactNode
  prevPath: Path
  nextPath: Path
  nextDisabled?: boolean
  nextVisible?: boolean
}

const EditorPage: FC<EditorPageProps> = ({
  title,
  description,
  children,
  prevPath,
  nextPath,
  nextDisabled,
  nextVisible,
}) => {
  const nav = useNavigate()

  return (
    <div className={editorPage}>
      <h1>{title}</h1>
      <p style={{ marginBottom: '1rem' }}>{description}</p>
      <div style={{ overflowY: 'auto' }}>{children}</div>
      <div
        style={{
          display: 'flex',
          justifyContent: 'center',
          padding: '0.5rem 0',
        }}
      >
        <Button
          type='button'
          onClick={() => nav(prevPath)}
          text='Back'
          icon='arrow-left'
          style={{
            marginRight: '0.5rem',
          }}
        />{' '}
        {nextVisible && (
          <Button
            type='button'
            onClick={() => nav(nextPath)}
            text='Next'
            intent='primary'
            rightIcon='arrow-right'
            disabled={nextDisabled}
          />
        )}
      </div>
    </div>
  )
}

EditorPage.defaultProps = {
  nextDisabled: false,
  nextVisible: true,
}

export default memo(EditorPage)
