import ErrorMessage from '@/components/ErrorMessage'
import { NonIdealState, Spinner } from '@blueprintjs/core'
import { useGetTeamEmailParticipant } from '@inject/graphql/queries/GetTeamEmailParticipant.generated'
import type { FC } from 'react'
import EmailFormOverlay from '.'

interface TraineeEmailFormOverlayProps {
  teamId: string
  exerciseId: string
}

const TraineeEmailFormOverlay: FC<TraineeEmailFormOverlayProps> = ({
  teamId,
  exerciseId,
}) => {
  const { data, loading, error } = useGetTeamEmailParticipant({
    variables: {
      teamId,
    },
    skip: !teamId,
  })

  if (loading) {
    return <Spinner />
  }
  if (error) {
    return (
      <ErrorMessage>
        <h1>Error occurred!</h1>
        <p>{error.message}</p>
      </ErrorMessage>
    )
  }
  if (!data || !data.teamEmailParticipant) {
    return (
      <NonIdealState
        icon='low-voltage-pole'
        title='No data'
        description='Please wait for the data to come in'
      />
    )
  }

  return (
    <EmailFormOverlay
      teamId={teamId}
      emailForm='trainee'
      exerciseId={exerciseId}
      teamAddress={data.teamEmailParticipant.address}
    />
  )
}

export default TraineeEmailFormOverlay
