import { useModals } from '@/router'
import {
  Button,
  ButtonGroup,
  NonIdealState,
  Section,
  SectionCard,
} from '@blueprintjs/core'
import Reloader from '@inject/graphql/components/Reloader'
import { useGetDefinitions } from '@inject/graphql/queries/GetDefinitions.generated'
import CardList from '@inject/shared/components/CardList'
import notEmpty from '@inject/shared/utils/notEmpty'
import Definition from './components/Definition'

const DefinitionManager = () => {
  const { data, refetch } = useGetDefinitions()
  const { open } = useModals()

  const definitions = (data?.definitions || []).filter(notEmpty)
  return (
    <Section
      title='Definitions'
      rightElement={
        <ButtonGroup onClick={e => e.stopPropagation()}>
          {/* TODO: set as active when uploader is open */}
          <Button
            onClick={() => {
              open('/instructor/definitionUploader')
            }}
            icon='upload'
          >
            Upload
          </Button>
          <Reloader onRefetch={refetch} />
        </ButtonGroup>
      }
      collapsible
    >
      <SectionCard>
        {definitions.length === 0 ? (
          <NonIdealState
            icon='low-voltage-pole'
            title='No definitions found'
            description='There are no definitions to display'
          />
        ) : (
          <CardList>
            {definitions.map(definition => (
              <Definition key={definition.id} definition={definition} />
            ))}
          </CardList>
        )}
      </SectionCard>
    </Section>
  )
}

export default DefinitionManager
