import { Section, SectionCard } from '@blueprintjs/core'
import { css } from '@emotion/css'
import type { TeamLearningObjective } from '@inject/graphql/fragments/TeamLearningObjective.generated'
import type { FC } from 'react'
import LearningActivity from './LearningActivity'

const activities = css`
  display: flex;
  flex-direction: column;
  gap: 1rem;
`

interface LearningObjectiveProps {
  objective: TeamLearningObjective
  teamId: string
}

const LearningObjective: FC<LearningObjectiveProps> = ({
  objective,
  teamId,
}) => (
  <Section
    title={objective.objective.name}
    subtitle={objective.objective.tags}
    collapsible
    icon={objective.reached ? 'tick' : undefined}
  >
    <SectionCard className={activities}>
      {objective.activities.map(activity => (
        <LearningActivity
          key={activity.id}
          activity={activity}
          teamId={teamId}
        />
      ))}
    </SectionCard>
  </Section>
)

export default LearningObjective
