import ErrorMessage from '@/components/ErrorMessage'
import { Button, InputGroup, NonIdealState } from '@blueprintjs/core'
import { css } from '@emotion/css'
import useApolloClient from '@inject/graphql/client/useApolloClient'
import { useLogin } from '@inject/graphql/mutations/Login.generated'
import type { Identity } from '@inject/graphql/queries/Identity.generated'
import { IdentityDocument } from '@inject/graphql/queries/Identity.generated'
import type { MutableRefObject } from 'react'
import { useMemo, useRef, useState } from 'react'
import { useNavigate } from 'react-router-dom'

const loginForm = css`
  display: flex;
  flex-direction: column;
  gap: 1rem;
  margin: 0 auto;
  max-width: 30rem;
  padding: 1rem;
  width: 100%;
`

enum LoginState {
  LOGIN,
  LOGIN_SUCCESS,
}

const Login = () => {
  const nav = useNavigate()
  const apollo = useApolloClient()

  const username = useRef('')
  const password = useRef('')

  const [state, setState] = useState(LoginState.LOGIN)

  const [login, { loading, error }] = useLogin({
    onCompleted: data => {
      if (data.login?.user) {
        setState(LoginState.LOGIN_SUCCESS)
        apollo.writeQuery<Identity>({
          query: IdentityDocument,
          data: { whoAmI: data.login?.user },
          overwrite: true,
        })
        setTimeout(() => {
          nav('/')
        }, 1000) // Redirect to home page after 1 second, this hack allows Cookie to set properly
      }
    },
  })

  const handleSubmit = useMemo(
    () =>
      (
        username: MutableRefObject<string>,
        password: MutableRefObject<string>
      ) =>
      (e: React.FormEvent<HTMLFormElement>) => {
        e.preventDefault()
        login({
          variables: { username: username.current, password: password.current },
        })
      },
    [login]
  )

  const LoginForm = () => (
    <form onSubmit={handleSubmit(username, password)} className={loginForm}>
      <InputGroup
        type='username'
        onChange={e => (username.current = e.target.value)}
        placeholder='Email'
      />
      <InputGroup
        type='password'
        onChange={e => (password.current = e.target.value)}
        placeholder='Password'
      />
      <Button type='submit' loading={loading} intent='primary'>
        Login
      </Button>
    </form>
  )

  return (
    <>
      {state === LoginState.LOGIN_SUCCESS && (
        <div>
          <NonIdealState
            icon='tick-circle'
            title='Login successful'
            description='Redirecting to home page...'
          />
        </div>
      )}
      {state === LoginState.LOGIN && <LoginForm />}
      {error && (
        <div className={loginForm}>
          <ErrorMessage>{error.message}</ErrorMessage>
        </div>
      )}
    </>
  )
}

export default Login
